@@ -32,6 +32,7 @@ class ConfWindow: public Gtk::Window
 		~ConfWindow();
 		void on_button_save();
 		void on_button_cancel();
+		void on_button_color_set();
 		bool on_delete_event(GdkEventAny*);
 		typedef sigc::signal<void> type_signal_quit;
 		type_signal_quit signal_quit()
@@ -44,11 +45,13 @@ class ConfWindow: public Gtk::Window
 		type_signal_quit signal_quit_;
 		VariablesMap* m_pVariablesMap;
 		Gtk::ComboBoxText* cbtheme;
+		Gtk::ColorButton* colorBt;
 		Glib::ustring			m_depth;
 		Glib::ustring			m_step_time;
 		Glib::ustring			m_play_time;
 		Glib::ustring			m_theme;
 		Glib::ustring			m_engine_name;
+		Glib::ustring			m_line_color;
 		bool				m_size_big;
 		bool				m_usebook;
 
