@@ -214,15 +214,6 @@ void Engine::init_snapshot(const char* fen)
 	move_snapshots.push_back(0);
 
 	sync_board();
-	/*
-	int i,j;
-	for(i=0;i<16;i++)
-	{
-		for(j=0;j<16;j++)
-			printf(" %2d ",chessboard[i*16+j]);
-		printf("\n");
-	}
-	*/
 }
 
 void Engine::get_snapshot(int num)
@@ -231,6 +222,7 @@ void Engine::get_snapshot(int num)
 	//DLOG("get_snapshot = %s\n",fens.c_str());
 	clean_board();
 	from_fens(fens.c_str());
+	current_fen_snapshots = fens;
 
 	sync_board();
 
@@ -646,10 +638,12 @@ bool Engine::logic_move(int mv)
 	if(!in_board(dst))
 		return false;
 	/** 检测是否同为红方的笨办法 */
-	if((chessboard[src]&16) && (chessboard[eated]&16))
+	//if((chessboard[src]&16) && (chessboard[eated]&16))
+	if((chessboard[src]&16) && (chessboard[dst]&16))
 			return false;
 	/** 检测是否同为黑方的笨办法 */
-	if((chessboard[src]&32) && (chessboard[eated]&32))
+	//if((chessboard[src]&32) && (chessboard[eated]&32))
+	if((chessboard[src]&32) && (chessboard[dst]&32))
 			return false;
 
 	/** 判断是否过河的方法，dst & 0x80,在下方是非0, 上方是0 */
@@ -934,6 +928,7 @@ int Engine::do_move(int mv)
 	char str_fen[128];
 	to_fens(str_fen);
 	fen_snapshots.push_back(std::string(str_fen));
+	current_fen_snapshots = std::string(str_fen);
 
 	add_move_chinese(mv_line);
 
@@ -2215,3 +2210,138 @@ void Engine::sync_board()
 	revchessboard[255]=0;
 }
 
+void Engine::gen_which_can_move(std::vector<Gdk::Point>& points, int chess_, bool rev)
+{
+	int sx,sy;
+	get_xy_from_chess(chess_,sx,sy,rev);
+	int chess_t = get_chessman_type(chess_);
+	int src = get_chessman_xy(chess_);
+	switch(chess_t){
+		/** 将/帅的着法，同一纵线或横线，移动只一个单位，在九宫内*/
+		case RED_PAWN:
+		case BLACK_PAWN:
+		case RED_KING:
+		case BLACK_KING:
+			{
+				//计算合法的能走的点再加入potins中
+			int dst = get_dst_xy(sx+1,sy, rev);
+			int mv = get_move(src, dst);
+			if(logic_move(mv))
+				points.push_back(Gdk::Point(sx+1, sy));
+			dst = get_dst_xy(sx-1,sy, rev);
+			mv = get_move(src, dst);
+			if(logic_move(mv))
+				points.push_back(Gdk::Point(sx-1, sy));
+			dst = get_dst_xy(sx,sy+1, rev);
+			mv = get_move(src, dst);
+			if(logic_move(mv))
+				points.push_back(Gdk::Point(sx, sy+1));
+			dst = get_dst_xy(sx,sy-1, rev);
+			mv = get_move(src, dst);
+			if(logic_move(mv))
+				points.push_back(Gdk::Point(sx, sy-1));
+			}
+			break;
+		case RED_ADVISOR:
+		case BLACK_ADVISOR:
+			{
+				int dst = get_dst_xy(sx+1,sy+1, rev);
+				int mv = get_move(src, dst);
+				if(logic_move(mv))
+					points.push_back(Gdk::Point(sx+1, sy+1));
+				dst = get_dst_xy(sx+1,sy-1, rev);
+				mv = get_move(src, dst);
+				if(logic_move(mv))
+					points.push_back(Gdk::Point(sx+1, sy-1));
+				dst = get_dst_xy(sx-1,sy-1, rev);
+				mv = get_move(src, dst);
+				if(logic_move(mv))
+					points.push_back(Gdk::Point(sx-1, sy-1));
+				dst = get_dst_xy(sx-1,sy+1, rev);
+				mv = get_move(src, dst);
+				if(logic_move(mv))
+					points.push_back(Gdk::Point(sx-1, sy+1));
+			}
+			break;
+		case RED_BISHOP:
+		case BLACK_BISHOP:
+			{
+				int dst = get_dst_xy(sx+2,sy+2,rev);
+				int mv = get_move(src,dst);
+				if(logic_move(mv))
+						points.push_back(Gdk::Point(sx+2,sy+2));
+				dst = get_dst_xy(sx+2, sy-2, rev);
+				mv = get_move(src,dst);
+				if(logic_move(mv))
+						points.push_back(Gdk::Point(sx+2,sy-2));
+				dst = get_dst_xy(sx-2, sy+2, rev);
+				mv = get_move(src,dst);
+				if(logic_move(mv))
+						points.push_back(Gdk::Point(sx-2,sy+2));
+				dst = get_dst_xy(sx-2, sy-2, rev);
+				mv = get_move(src,dst);
+				if(logic_move(mv))
+						points.push_back(Gdk::Point(sx-2,sy-2));
+			}
+			break;
+		case RED_KNIGHT:
+		case BLACK_KNIGHT:
+			{
+				int dst = get_dst_xy(sx+1,sy+2,rev);
+				int mv = get_move(src,dst);
+				if(logic_move(mv))
+						points.push_back(Gdk::Point(sx+1,sy+2));
+				dst = get_dst_xy(sx+1, sy-2, rev);
+				mv = get_move(src,dst);
+				if(logic_move(mv))
+						points.push_back(Gdk::Point(sx+1,sy-2));
+				dst = get_dst_xy(sx-1, sy-2, rev);
+				mv = get_move(src,dst);
+				if(logic_move(mv))
+						points.push_back(Gdk::Point(sx-1,sy-2));
+				dst = get_dst_xy(sx-1, sy+2, rev);
+				mv = get_move(src,dst);
+				if(logic_move(mv))
+						points.push_back(Gdk::Point(sx-1,sy+2));
+				dst = get_dst_xy(sx-2, sy+1, rev);
+				mv = get_move(src,dst);
+				if(logic_move(mv))
+						points.push_back(Gdk::Point(sx-2,sy+1));
+				dst = get_dst_xy(sx-2, sy-1, rev);
+				mv = get_move(src,dst);
+				if(logic_move(mv))
+						points.push_back(Gdk::Point(sx-2,sy-1));
+				dst = get_dst_xy(sx+2, sy+1, rev);
+				mv = get_move(src,dst);
+				if(logic_move(mv))
+						points.push_back(Gdk::Point(sx+2,sy+1));
+				dst = get_dst_xy(sx+2, sy-1, rev);
+				mv = get_move(src,dst);
+				if(logic_move(mv))
+						points.push_back(Gdk::Point(sx+2,sy-1));
+			}
+			break;
+		case RED_ROOK:
+		case BLACK_ROOK:
+		case RED_CANNON:
+		case BLACK_CANNON:
+			{
+				for(int i = -9; i<9; ++i){
+					int dst = get_dst_xy(sx,sy+i);
+					int mv = get_move(src,dst);
+					if(logic_move(mv))
+						points.push_back(Gdk::Point(sx,sy+i));
+					dst = get_dst_xy(sx+i, sy);
+					mv = get_move(src,dst);
+					if(logic_move(mv))
+						points.push_back(Gdk::Point(sx+i,sy));
+				}
+
+			}
+			break;
+
+	}
+
+
+
+}
